@@ -121,6 +121,60 @@ class DriveCreateForm(NetBoxModelForm):
         return drive
 
 
+class DriveEditForm(NetBoxModelForm):
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the drive e.g. 25",
+        validators=[MinValueValidator(0.1)],
+    )
+    cluster_type = DynamicModelChoiceField(
+        required=False,
+        queryset=ClusterType.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
+    cluster = DynamicModelChoiceField(
+        queryset=Cluster.objects.all(),
+        query_params={
+            'type_id': '$cluster_type'  # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        },
+        help_text="The Storage Cluster of the drive",
+    )
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
+    )
+
+    fieldsets = (
+        (
+            "Drive Configuration Items",
+            (
+                "cluster_type",
+                "cluster",
+                "size",
+                "description"
+            ),
+        ),
+    )
+
+    class Meta:
+        model = Drive
+
+        fields = (
+            "size",
+            "cluster",
+            "description",
+        )
+
+    def save(self, *args, **kwargs):
+        drive = super().save(*args, **kwargs)
+        drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+        linux_device_drive = LinuxDevice.objects.get(object_id=drive.pk,content_type_id=drive_type_pk)
+        linux_device_drive.size = self.cleaned_data['size']
+        linux_device_drive.save()
+        return drive
+
+
 class DriveFilterForm(NetBoxModelFilterSetForm):
     """Form for filtering Drive instances."""
 
