@@ -5,6 +5,7 @@ from netbox_storage.forms import (
     DriveImportForm,
     DriveFilterForm,
     DriveForm,
+    DriveEditForm,
     DriveBulkEditForm, DriveCreateForm
 )
 from netbox_storage.models import Drive, Partition
@@ -33,7 +34,7 @@ class DriveAddView(generic.ObjectEditView):
 
 class DriveEditView(generic.ObjectEditView):
     queryset = Drive.objects.all()
-    form = DriveForm
+    form = DriveEditForm
     default_return_url = "plugins:netbox_storage:drive_list"
 
 
